@@ -110,6 +110,7 @@ VERSION_NUM_LEN = UL_INT_SIZE_IN_BYTES
 VERSIONED_HELLO_MSG_MIN_PAYLOAD_LEN = UL_INT_SIZE_IN_BYTES + NETWORK_NUM_LEN + VERSION_NUM_LEN
 
 NODE_ID_SIZE_IN_BYTES = 16
+ACCOUNT_ID_SIZE_IN_BYTES = 36
 
 NULL_ENCRYPT_REPEAT_VALUE = "1"  # must be nonzero string character
 BLOXROUTE_HELLO_MESSAGES = [b"hello", b"ack"]
@@ -272,6 +273,9 @@ DECODED_EMPTY_SOURCE_ID = EMPTY_SOURCE_ID.decode()
 TRANSACTION_SERVICE_LOG_TRANSACTIONS_INTERVAL_S = 60 * 15
 TRANSACTION_SERVICE_TRANSACTIONS_HISTOGRAM_BUCKETS = 36
 
+EMPTY_ACCOUNT_ID = MSG_NULL_BYTE * 36
+DECODED_EMPTY_ACCOUNT_ID = EMPTY_ACCOUNT_ID.decode()
+
 # https://urllib3.readthedocs.io/en/latest/reference/urllib3.util.html#module-urllib3.util.retry
 HTTP_REQUEST_RETRIES_COUNT: int = 3
 HTTP_REQUEST_BACKOFF_FACTOR: float = 0.5
@@ -334,3 +338,8 @@ GC_MEDIUM_MEMORY_THRESHOLD = 1024 * 1024 * 1024 * 3.5
 GC_HIGH_MEMORY_THRESHOLD = 1024 * 1024 * 1024 * 4
 
 BLOCKS_FAILED_VALIDATION_HISTORY_SIZE = 10
+
+THROTTLE_RECONNECT_TIME_S = 15 * 60
+MAX_HIGH_RECONNECT_ATTEMPTS_ALLOWED = 10
+
+WAIT_FOR_SUBSCRIPTION_TIMEOUT = 60
