@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from enum import Enum
 from typing import Optional
 from datetime import datetime, date
 
@@ -15,6 +16,14 @@ logger = logging.get_logger(__name__)
 OPTIONAL_ACCOUNT_SERVICES = {"tx_free"}
 
 
+class Tiers(Enum):
+    INTRODUCTORY = "Introductory"
+    DEVELOPER = "Developer"
+    PROFESSIONAL = "Professional"
+    ENTERPRISE = "Enterprise"
+    ENTERPRISE_ELITE = "EnterpriseElite"
+
+
 @dataclass
 class AccountInfo:
     account_id: str
@@ -45,6 +54,7 @@ class AccountTemplate:
     private_relays: Optional[BdnPrivateRelayServiceModelConfigBase] = None
     private_transaction: Optional[BdnQuotaServiceModelConfigBase] = None
     private_transaction_fee: Optional[BdnQuotaServiceModelConfigBase] = None
+    light_gateway: Optional[BdnBasicServiceModel] = None
 
 
 @dataclass
