@@ -24,7 +24,7 @@ ALL_KEY = "all"
 POOLS_PARAMS_KEY = "pools"
 DETAIL_RESPONSE_PARAM_KEY = "detail_response"
 SYNCHRONOUS_PARAMS_KEY = "synchronous"
-SMART_MONITORING_PARAMS_KEY = "smart_monitoring"
+MONITOR_SPEEDUP_PARAMS_KEY = "monitor_speedup"
 STATUS_TRACK_PARAMS_KEY = "status_track"
 NONCE_MONITORING_PARAMS_KEY = "nonce_monitoring"
 DETAILS_LEVEL_PARAMS_KEY = "details_level"
@@ -52,6 +52,7 @@ DEFAULT_RPC_USER = ""
 DEFAULT_RPC_PASSWORD = ""
 DEFAULT_RPC_BASE_SSL_URL = ""
 MAINNET_NETWORK_NAME = "Mainnet"
+DEFAULT_BLOCKCHAIN_PROTOCOL = "Ethereum"
 CLOUD_API_URL = "https://api.blxrbdn.com"
 
 JSON_RPC_VERSION = "2.0"
@@ -67,7 +68,7 @@ JSON_RPC_ERROR_CODE = "code"
 
 NEW_TRANSACTION_FEED_NAME = "newTxs"
 NEW_BLOCKS_FEED_NAME = "newBlocks"
-ETH_ON_BLOCK_FEED_NAME = "ethOnBlock"
+ETH_ON_BLOCK_FEED_NAME = "onBlock"
 ETH_PENDING_TRANSACTION_FEED_NAME = "pendingTxs"
 TRANSACTION_STATUS_FEED_NAME = "transactionStatus"
 ETH_TRANSACTION_RECEIPTS_FEED_NAME = "txReceipts"
