@@ -19,7 +19,7 @@ class RpcRequestType(SerializeableEnum):
     TX_SERVICE = 14
     ADD_BLOCKCHAIN_PEER = 15
     REMOVE_BLOCKCHAIN_PEER = 16
-    START_MONITOR_TRANSACTION_BY_HASH = 17
+    _START_MONITOR_TRANSACTION_BY_HASH = 17
     STOP_MONITOR_TRANSACTION = 18
     LIST_ALL_MONITORED_TRANSACTIONS = 19
     BLXR_PRIVATE_TX = 20
@@ -30,3 +30,9 @@ class RpcRequestType(SerializeableEnum):
     NETWORK_TX_FEE_UPDATE = 25
     BLXR_SIMULATE_BUNDLE = 26
     BLXR_SUBMIT_BUNDLE = 27
+    BLXR_PROFIT_SHARING_PRIVATE_TX = 28
+    METAMASK_PRIVATE_TX = 29
+    SIMULATE_ARB_ONLY_BUNDLE = 30
+    SUBMIT_ARB_ONLY_BUNDLE = 31
+    BLXR_INFO = 32
+    BACKRUN_PRIVATE_TX = 33
