@@ -36,6 +36,7 @@ NODE_TO_CONNECTION_TYPE: Dict[NodeType, Dict[NodeType, ConnectionType]] = {
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
         NodeType.RELAY_TRANSACTION: ConnectionType.CROSS_RELAY,
         NodeType.RELAY_BLOCK: ConnectionType.RELAY_BLOCK,
+        NodeType.RELAY_PROXY: ConnectionType.RELAY_PROXY,
         NodeType.RELAY: ConnectionType.RELAY_ALL,
         NodeType.API_SOCKET: ConnectionType.SDN
     },
@@ -44,6 +45,7 @@ NODE_TO_CONNECTION_TYPE: Dict[NodeType, Dict[NodeType, ConnectionType]] = {
         NodeType.INTERNAL_GATEWAY: ConnectionType.INTERNAL_GATEWAY,
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
         NodeType.RELAY_TRANSACTION: ConnectionType.RELAY_TRANSACTION,
+        NodeType.RELAY_PROXY: ConnectionType.RELAY_PROXY,
         NodeType.RELAY_BLOCK: ConnectionType.CROSS_RELAY,
         NodeType.RELAY: ConnectionType.RELAY_ALL,
         NodeType.API_SOCKET: ConnectionType.SDN
@@ -53,8 +55,9 @@ NODE_TO_CONNECTION_TYPE: Dict[NodeType, Dict[NodeType, ConnectionType]] = {
         NodeType.INTERNAL_GATEWAY: ConnectionType.INTERNAL_GATEWAY,
         NodeType.EXTERNAL_GATEWAY: ConnectionType.EXTERNAL_GATEWAY,
         NodeType.RELAY: ConnectionType.RELAY_ALL,
-        NodeType.API_SOCKET: ConnectionType.SDN
-    }
+        NodeType.RELAY_PROXY: ConnectionType.RELAY_PROXY,
+        NodeType.API_SOCKET: ConnectionType.SDN,
+    },
 }
 
 
