@@ -1,5 +1,5 @@
 import base64
-from typing import Union, List, Optional, Dict
+from typing import Union, Optional, Dict
 
 from bxcommon.utils.object_hash import Sha256Hash
 from bxcommon.utils.stats.network_content_event_type import NetworkContent
@@ -12,12 +12,13 @@ class _NetworkStatisticsService:
     def __init__(self) -> None:
         self.name = "NetworkContent"
         self.log_level = LogLevel.STATS
-        self.logger = logging.get_logger(LogRecordType.NetworkContent)
+        self.logger_tx = logging.get_logger(LogRecordType.NetworkContentTx)
+        self.logger_block = logging.get_logger(LogRecordType.NetworkContentBlock)
 
     def transactions_log_event(
             self, network_num: int, tx_hash: Sha256Hash, tx_content: Union[bytearray, memoryview],
             more_info: Optional[Dict] = None) -> None:
-        self.logger.log(
+        self.logger_tx.log(
             self.log_level,
             {
                 "data": {
@@ -33,7 +34,7 @@ class _NetworkStatisticsService:
     def block_content_log_event(
             self, network_num: int, block_hash: Sha256Hash, block_content: memoryview, more_info: Optional[Dict] = None
     ) -> None:
-        self.logger.log(
+        self.logger_block.log(
             self.log_level,
             {
                 "data": {
@@ -46,20 +47,5 @@ class _NetworkStatisticsService:
             }
         )
 
-    def block_transactions_log_event(
-            self, network_num: int, block_hash: Sha256Hash, block_transactions: List[Sha256Hash]
-    ) -> None:
-        self.logger.log(
-            self.log_level,
-            {
-                "data": {
-                    "network_num": network_num,
-                    "block_hash": block_hash.binary.hex(),
-                    "block_transactions": block_transactions
-                },
-                "type": NetworkContent.BLOCK_TRANSACTIONS
-            }
-        )
-
 
 connection_stats = _NetworkStatisticsService()
