@@ -22,7 +22,7 @@ class EthRelayConnection(AbstractRelayConnection):
         gas_price = eth_common_utils.raw_tx_gas_price(tx_contents, 0)
         if gas_price >= self.node.get_network_min_transaction_fee():
             self.node.feed_manager.publish_to_feed(
-                FeedKey(EthNewTransactionFeed.NAME),
+                FeedKey(EthNewTransactionFeed.NAME, network_num=self.node.network_num),
                 EthRawTransaction(
                     tx_hash, tx_contents, FeedSource.BDN_SOCKET, local_region=local_region
                 )
