@@ -114,3 +114,5 @@ CHECK_RELAY_CONNECTIONS_DELAY_S = 5
 ETH_MIN_GAS_INTERVAL_S = 5 * 60
 
 ETH_PROTOCOL_VERSION_63 = 63
+ONE_DAY_INTERVAL_S = 60 * 60 * 24
+ONE_HOUR_INTERVAL_S = 60 * 60
\ No newline at end of file
